@@ -7,7 +7,7 @@ import logging
 import grpc
 
 from preseem import PreseemGrpcClient
-from preseem_protobuf.network_poller.network_poller_pb2 import NetworkElementUpdate, SendUpdateBatchRequest
+from preseem_protobuf.network_poller.network_poller_pb2 import NetworkElementUpdate, SendUpdateBatchRequest, GetUpdatesRequest
 from preseem_protobuf.network_poller.network_poller_pb2_grpc import NetworkPollerServiceStub
 
 class NetworkPollerGrpcClient:
@@ -41,6 +41,17 @@ class NetworkPollerGrpcClient:
         if self._client:
             self._client = None
 
+    async def get_updates(self, company_uuid=None):
+        if not self._client:
+            return
+        if not self._svc:
+            await self._client.connect()
+            self._svc = NetworkPollerServiceStub(self._client._channel)
+        req = GetUpdatesRequest()
+        if company_uuid:
+            req.company_uuid = company_uuid
+        return await self._client._grpc_op(self._svc.GetUpdates, req, collect_results=True)
+
     async def _post(self, messages):
         """Post a list of NetworkElementUpdate messages"""
         if not self._client:
